bayespy.nodes.Categorical
=========================

.. currentmodule:: bayespy.nodes

.. autoclass:: Categorical

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Categorical.__init__
      ~Categorical.add_plate_axis
      ~Categorical.broadcasting_multiplier
      ~Categorical.delete
      ~Categorical.get_gradient
      ~Categorical.get_mask
      ~Categorical.get_moments
      ~Categorical.get_parameters
      ~Categorical.get_riemannian_gradient
      ~Categorical.get_shape
      ~Categorical.has_plotter
      ~Categorical.initialize_from_parameters
      ~Categorical.initialize_from_prior
      ~Categorical.initialize_from_random
      ~Categorical.initialize_from_value
      ~Categorical.load
      ~Categorical.logpdf
      ~Categorical.lower_bound_contribution
      ~Categorical.lowerbound
      ~Categorical.move_plates
      ~Categorical.observe
      ~Categorical.pdf
      ~Categorical.plot
      ~Categorical.random
      ~Categorical.save
      ~Categorical.set_parameters
      ~Categorical.set_plotter
      ~Categorical.show
      ~Categorical.unobserve
      ~Categorical.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Categorical.dims
      ~Categorical.plates
      ~Categorical.plates_multiplier
   
   